@@ -61,6 +61,7 @@ import java.util.Date;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
+import javax.net.ssl.SSLHandshakeException;
 import org.apache.commons.io.FileUtils;
 import org.json.JSONArray;
 import org.json.JSONException;
@@ -71,9 +72,11 @@ import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.Category;
+import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
 import com.openexchange.html.HtmlService;
 import com.openexchange.java.Strings;
+import com.openexchange.net.ssl.exception.SSLExceptionCode;
 import com.openexchange.rss.RssExceptionCodes;
 import com.openexchange.rss.RssResult;
 import com.openexchange.rss.osgi.Services;
@@ -121,7 +124,7 @@ public class RssAction implements AJAXActionService {
     // ------------------------------------------------------------------------------------------------------------------------------
 
     private final TimoutHttpURLFeedFetcher fetcher;
-    private final HashMapFeedInfoCache feedCache;
+    private final HashMapFeedInfoCache     feedCache;
 
     /**
      * Initializes a new {@link RssAction}.
@@ -229,6 +232,10 @@ public class RssAction implements AJAXActionService {
         if (sort.equalsIgnoreCase("DATE")) {
             Collections.sort(results, "DESC".equalsIgnoreCase(order) ? DESC : ASC);
         }
+        int limit = request.getIntParameter("limit");
+        if (limit > 0 && limit < results.size()) {
+            results = results.subList(0, limit);
+        }
 
         return new AJAXRequestResult(results, "rss").addWarnings(warnings);
     }
@@ -291,7 +298,12 @@ public class RssAction implements AJAXActionService {
             } catch (UnsupportedEncodingException e) {
                 /* yeah, right... not happening for UTF-8 */
             } catch (IOException e) {
-                OXException oxe = RssExceptionCodes.IO_ERROR.create(e, e.getMessage(), url.toString());
+                OXException oxe;
+                if (ExceptionUtils.isEitherOf(e, SSLHandshakeException.class)) {
+                    oxe = SSLExceptionCode.UNTRUSTED_CERTIFICATE.create(e, url.getHost());
+                } else {
+                    oxe = RssExceptionCodes.IO_ERROR.create(e, e.getMessage(), url.toString());
+                }
                 if (1 == urls.size()) {
                     throw oxe;
                 }
@@ -351,17 +363,10 @@ public class RssAction implements AJAXActionService {
     }
 
     /**
-<<<<<<< HEAD
-     * Sanitises the specified string via the {@link HtmlService}
-     *
-     * @param string The string to sanitise
-     * @return The sanitised string if the {@link HtmlService} is available
-=======
      * Sanitizes the specified string via the {@link HtmlService}
      *
      * @param string The string to sanitize
      * @return The sanitized string as HTML content if the {@link HtmlService} is available
->>>>>>> 88a3504f07c... Fix for bug 56420: Return RSS Feed's subject as-is
      */
     private static String sanitiseString(String string) throws OXException {
         final HtmlService htmlService = Services.getService(HtmlService.class);
