@@ -50,6 +50,7 @@
 package com.openexchange.rss.util;
 
 import static com.openexchange.java.Autoboxing.I;
+import com.google.common.collect.ImmutableSet;
 import java.io.BufferedInputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -58,17 +59,20 @@ import java.net.InetAddress;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLConnection;
-import java.util.HashMap;
-import java.util.Map;
-import java.util.zip.GZIPInputStream;
 import java.net.UnknownHostException;
 import java.util.Set;
-import com.google.common.collect.ImmutableSet;
+import java.util.zip.GZIPInputStream;
+import javax.net.ssl.HttpsURLConnection;
+import javax.net.ssl.SSLSocketFactory;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Interests;
 import com.openexchange.config.Reloadable;
+import com.openexchange.config.Reloadables;
 import com.openexchange.java.InetAddresses;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
+import com.openexchange.net.ssl.SSLSocketFactoryProvider;
+import com.openexchange.net.ssl.TrustedSSLSocketFactory;
 import com.openexchange.rss.osgi.Services;
 import com.openexchange.tools.stream.CountingInputStream;
 import com.sun.syndication.feed.synd.SyndFeed;
@@ -214,6 +218,13 @@ public class TimoutHttpURLFeedFetcher extends AbstractFeedFetcher implements Rel
             }
 
             HttpURLConnection httpConnection = (HttpURLConnection) connection;
+            if ("https".equals(feedUrl.getProtocol()) || 443 == feedUrl.getPort()) {
+                HttpsURLConnection httpsConnection = (HttpsURLConnection) httpConnection;
+                SSLSocketFactory sslSocketFactory = Services.getService(SSLSocketFactoryProvider.class).getDefault();
+                HttpsURLConnection.setDefaultSSLSocketFactory(sslSocketFactory);
+                httpConnection = httpsConnection;
+            }
+
             if (connectTimout > 0) {
                 httpConnection.setConnectTimeout(connectTimout);
             }
@@ -449,26 +460,14 @@ public class TimoutHttpURLFeedFetcher extends AbstractFeedFetcher implements Rel
         return syndFeedInput.build(reader);
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.config.Reloadable#reloadConfiguration(com.openexchange.config.ConfigurationService)
-     */
     @Override
     public void reloadConfiguration(ConfigurationService configService) {
         maximumAllowedSize = configService.getIntProperty(MAX_FEED_SIZE_PROPERTY_NAME, 4194304);
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.config.Reloadable#getConfigFileNames()
-     */
     @Override
-    public Map<String, String[]> getConfigFileNames() {
-        Map<String, String[]> filenames = new HashMap<String, String[]>(1);
-        filenames.put("rssmessaging.propertes", new String[] { MAX_FEED_SIZE_PROPERTY_NAME });
-        return filenames;
+    public Interests getInterests() {
+        return Reloadables.interestsForProperties(MAX_FEED_SIZE_PROPERTY_NAME);
     }
 
     /**
